.. Macros/Configuration//BOOST_MPL_CFG_NO_HAS_XXX |20

BOOST_MPL_CFG_NO_HAS_XXX
========================

Synopsis
--------

.. parsed-literal::

    // #define BOOST_MPL_CFG_NO_HAS_XXX


Description
-----------

``BOOST_MPL_CFG_NO_HAS_XXX`` is an boolean configuration macro 
signaling availability of the |BOOST_MPL_HAS_XXX_TRAIT_DEF| / 
|BOOST_MPL_HAS_XXX_TRAIT_NAMED_DEF| introspection macros' functionality 
on a particular compiler.


See also
--------

|Macros|, |Configuration|, |BOOST_MPL_HAS_XXX_TRAIT_DEF|, |BOOST_MPL_HAS_XXX_TRAIT_NAMED_DEF|


.. copyright:: Copyright ©  2001-2009 Aleksey Gurtovoy and David Abrahams
   Distributed under the Boost Software License, Version 1.0. (See accompanying
   file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
